@@ -24,6 +24,12 @@ config['target'] = 'html'               # target type: HTML
 config['encoding'] = 'iso-8859-1'       # document encoding
 config['css-sugar'] = 1                 # CSS flag
 
+# The Pre (and Post) processing config is a list of lists:
+# [ [this, that], [foo, bar], [patt, replace] ]
+config['preproc'] = []
+config['preproc'].append(['nice','VERY NICE'])
+config['preproc'].append(['day','life'])
+
 # Let's do the conversion
 try:
 	headers   = txt2tags.doHeader(headers, config)
